==> devops-client-0.2.4-sources.jar: io/alauda/devops/client/dsl/BuildConfigOperation.java <==
/**
 * Copyright (C) 2018 Alauda
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.alauda.devops.client.dsl;

import io.alauda.kubernetes.client.dsl.MixedOperation;
import io.alauda.kubernetes.client.dsl.Secretable;
import io.alauda.kubernetes.client.dsl.Triggerable;
import io.alauda.kubernetes.client.dsl.Typeable;
import io.fabric8.openshift.api.model.Build;
import io.fabric8.openshift.api.model.BuildConfig;
import io.fabric8.openshift.api.model.BuildConfigList;
import io.fabric8.openshift.api.model.DoneableBuildConfig;
import io.fabric8.openshift.api.model.WebHookTrigger;
import io.alauda.devops.client.dsl.buildconfig.CommitterAuthorMessageAsFileTimeoutInputStreamable;

public interface BuildConfigOperation extends BuildConfigResource<BuildConfig, DoneableBuildConfig, Void, Build>,
  MixedOperation<BuildConfig, BuildConfigList, DoneableBuildConfig,BuildConfigResource<BuildConfig, DoneableBuildConfig, Void, Build>>,
  Typeable<Triggerable<WebHookTrigger, Void>>,
  Triggerable<WebHookTrigger, Void>,
  Secretable<Typeable<Triggerable<WebHookTrigger, Void>>>,
  CommitterAuthorMessageAsFileTimeoutInputStreamable<Build> {
}

==> devops-client-0.2.5-sources.jar: io/alauda/devops/client/dsl/BuildConfigOperation.java <==
/**
 * Copyright (C) 2018 Alauda
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.alauda.devops.client.dsl;

import io.alauda.kubernetes.client.dsl.MixedOperation;
import io.alauda.kubernetes.client.dsl.Secretable;
import io.alauda.kubernetes.client.dsl.Triggerable;
import io.alauda.kubernetes.client.dsl.Typeable;
import io.alauda.devops.api.model.Build;
import io.alauda.devops.api.model.BuildConfig;
import io.alauda.devops.api.model.BuildConfigList;
import io.alauda.devops.api.model.DoneableBuildConfig;
import io.alauda.devops.api.model.WebHookTrigger;
import io.alauda.devops.client.dsl.buildconfig.CommitterAuthorMessageAsFileTimeoutInputStreamable;

public interface BuildConfigOperation extends BuildConfigResource<BuildConfig, DoneableBuildConfig, Void, Build>,
  MixedOperation<BuildConfig, BuildConfigList, DoneableBuildConfig,BuildConfigResource<BuildConfig, DoneableBuildConfig, Void, Build>>,
  Typeable<Triggerable<WebHookTrigger, Void>>,
  Triggerable<WebHookTrigger, Void>,
  Secretable<Typeable<Triggerable<WebHookTrigger, Void>>>,
  CommitterAuthorMessageAsFileTimeoutInputStreamable<Build> {
}
